@@ -24,7 +24,6 @@ import (
 
 	"github.com/onsi/gomega"
 	"github.com/stretchr/testify/assert"
-	coretypes "k8s.io/api/core/v1"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -49,10 +48,10 @@ func TestCreateNamespace(t *testing.T) {
 	mgr, _ := manager.New(cfg, manager.Options{})
 	c = mgr.GetClient()
 
-	stopMgr, mgrStopped := StartTestManager(mgr, g)
+	stopFunc, mgrStopped := StartTestManager(mgr, g)
 
 	defer func() {
-		close(stopMgr)
+		stopFunc()
 		mgrStopped.Wait()
 	}()
 
@@ -101,7 +100,7 @@ func TestGetAllNamespaces(t *testing.T) {
 	var objMeta = metav1.ObjectMeta{
 		Name: "default",
 	}
-	var ns = coretypes.Namespace{
+	var ns = corev1.Namespace{
 		TypeMeta:   typeMeta,
 		ObjectMeta: objMeta,
 	}
